pub(super) struct Migrator<'a> {
conn: &'a mut PoolConnection<Db>,
}Expand description
Run migrations using a sqlx connection.
While SQLx has its own built-in migration functionality, we use Refinery, and alas we must support existing deployed databases which are already using Refinery to handle migrations. Rather than implement a tricky “migration of the migrations table”, or supporting separate migrations interfaces for databases deployed before and after the switch to SQLx, we continue using Refinery. This wrapper implements the Refinery traits for SQLx types.
Fields
conn: &'a mut PoolConnection<Db>Trait Implementations
Sourceimpl AsyncMigrate for Migrator<'_>
impl AsyncMigrate for Migrator<'_>
fn assert_migrations_table_query(migration_table_name: &str) -> String
fn get_last_applied_migration_query(migration_table_name: &str) -> String
fn get_applied_migrations_query(migration_table_name: &str) -> String
fn get_last_applied_migration<'life0, 'life1, 'async_trait>(
&'life0 mut self,
migration_table_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<Migration>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: Send + 'async_trait,
fn get_applied_migrations<'life0, 'life1, 'async_trait>(
&'life0 mut self,
migration_table_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: Send + 'async_trait,
fn migrate<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
migrations: &'life1 [Migration],
abort_divergent: bool,
abort_missing: bool,
grouped: bool,
target: Target,
migration_table_name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<Report, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: Send + 'async_trait,